/**
	MedusaLF
*/

package medusalf;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.*;
import javax.swing.plaf.*;
import javax.swing.plaf.metal.*;
import java.util.Vector;
import medusa.*;

public class MedusaLF extends MetalLookAndFeel
	implements java.io.Serializable
{

	public String getID()
	{
		return "Medusa";
	}

	public String getName()
	{
		return "Medusa Look and Feel";
	}

	public String getDescription()
	{
		return "Sample L&F from Swing";
	}

	public boolean isNativeLookAndFeel()
	{
		return false;
	}

	public boolean isSupportedLookAndFeel()
	{
		return true;
	}

// NEW
	protected void initClassDefaults(UIDefaults table)
	{
		super.initClassDefaults(table);
		
//		putDefault(table, "ButtonUI");
		putDefault(table, "CheckBoxUI");
		putDefault(table, "RadioButtonUI");
		putDefault(table, "ToolTipUI");

//		putDefault(table, "LabelUI");
	}

	protected void putDefault(UIDefaults table, String uiKey)
	{
		try 
		{
			String className = "medusalf.Medusa"+uiKey;
			Class buttonClass = Class.forName(className);
			table.put(uiKey, className);
			table.put(className, buttonClass);
		}
		catch (Exception ex) 
		{
			ex.printStackTrace();
		}

	}

	protected void initComponentDefaults(UIDefaults table)
	{
		super.initComponentDefaults(table);

		ColorUIResource commonBackground = new ColorUIResource(200,200,200);
		ColorUIResource commonForeground = new ColorUIResource(0, 0, 0);
		ColorUIResource buttonBackground = new ColorUIResource(108,108,108);
		ColorUIResource buttonForeground = new ColorUIResource(220,220,220);
		ColorUIResource buttonPressedBackground = new ColorUIResource(108,108,108);
		ColorUIResource menuBackground =   new ColorUIResource(152,152,152);
		
		ColorUIResource checkBackground = new ColorUIResource(108,108,108);
		ColorUIResource checkForeground = new ColorUIResource(220,220,220);

		ColorUIResource activeForeground = new ColorUIResource(255,255,255);
		ColorUIResource focusBorder =      new ColorUIResource(255,255,255);
    ColorUIResource transparent = new ColorUIResource(new Color(0,0,0,255));

/*
		BorderUIResource borderRaised =
			new BorderUIResource(new EtchedBorder(EtchedBorder.RAISED,
													new Color(230,230,230),
													new Color(100,100,100))
			);
		BorderUIResource borderLowered =
			new BorderUIResource(new EtchedBorder(EtchedBorder.LOWERED,
													new Color(230,230,230),
													new Color(100,100,100))
			);
*/
    BorderUIResource borderLine = new BorderUIResource(
      LineBorder.createBlackLineBorder());

		FontUIResource commonFont = new 
			FontUIResource("Arial", Font.BOLD, 12 );

		Icon check = new ImageIcon(ImageCache.getImage("check.gif"));
		Icon bullet = new ImageIcon(ImageCache.getImage("bullet.gif"));

		Icon ubox = new ImageIcon(ImageCache.getImage("ubox.gif"));
		Icon ubull = new ImageIcon(ImageCache.getImage("ubull.gif"));

// NEW
		Icon cbox = new ImageIcon(ImageCache.getImage("cbox.gif"));
		Icon pcbox = new ImageIcon(ImageCache.getImage("p_cbox.gif"));
		Icon pubox = new ImageIcon(ImageCache.getImage("p_ubox.gif"));

		Icon cbull = new ImageIcon(ImageCache.getImage("cbull.gif"));
		Icon pcbull = new ImageIcon(ImageCache.getImage("p_cbull.gif"));
		Icon pubull = new ImageIcon(ImageCache.getImage("p_ubull.gif"));

		Object[] defaults =
		{
      "ToolTip.font", commonFont,

			"Button.font", commonFont,
			"Button.background", buttonBackground,
			"Button.foreground", buttonForeground,
			"Button.border", borderLine,
			"Button.borderPressed", borderLine,
			"Button.margin", new InsetsUIResource(8,8,8,8),
			"Button.textIconGap", new Integer(4),
			"Button.textShiftOffset", new Integer(2),
			"Button.focusBorder", focusBorder,
			"Button.activeForeground", new ColorUIResource(255, 255, 255),
			"Button.pressedBackground", buttonPressedBackground,

			"CheckBox.font", commonFont,
			"CheckBox.background", transparent,
			"CheckBox.foreground", checkForeground,
			"CheckBox.icon", new IconUIResource(ubox),
// NEW
			"CheckBox.checkBackground", checkBackground,
			"CheckBox.checkForeground", checkForeground,
			"CheckBox.focusBorder", focusBorder,
			"CheckBox.activeForeground", activeForeground,
			"CheckBox.iconPressed", new IconUIResource(pubox),
			"CheckBox.iconChecked", new IconUIResource(cbox),
			"CheckBox.iconPressedChecked", new IconUIResource(pcbox),
			"CheckBox.textIconGap", new Integer(4),
			
			"Label.font", commonFont,
			"Label.background", transparent,
			"Label.foreground", commonForeground,
			
			"MenuBar.font", commonFont,
			"MenuBar.background", menuBackground,
			"MenuBar.foreground", commonForeground,
			
			"Menu.font", commonFont,
			"Menu.background", menuBackground,
			"Menu.foreground", commonForeground,
			"Menu.selectionBackground", buttonBackground,
			"Menu.selectionForeground", buttonForeground,

			"CheckBoxMenuItem.font", commonFont,
			"CheckBoxMenuItem.background", menuBackground,
			"CheckBoxMenuItem.foreground", commonForeground,

			"MenuItem.font", commonFont,
			"MenuItem.background", menuBackground,
			"MenuItem.foreground", commonForeground,
			"MenuItem.selectionBackground", buttonBackground,
			"MenuItem.selectionForeground", buttonForeground,
			"MenuItem.margin", new InsetsUIResource(2, 2, 2, 2),

			"Panel.background", commonBackground,
			"Panel.foreground", commonForeground,

			"RadioButton.font", commonFont,
			"RadioButton.background", commonBackground,
			"RadioButton.foreground", checkForeground,
			"RadioButton.icon", new IconUIResource(ubull),
// NEW
			"RadioButton.focusBorder", focusBorder,
			"RadioButton.activeForeground", activeForeground,
			"RadioButton.iconPressed", new IconUIResource(pubull),
			"RadioButton.iconChecked", new IconUIResource(cbull),
			"RadioButton.iconPressedChecked", new IconUIResource(pcbull),
			"RadioButton.textIconGap", new Integer(4),

			"TextArea.margin", new InsetsUIResource(2, 2, 2, 2),
			"TextArea.background", new ColorUIResource(Color.white),
			"TextArea.foreground", new ColorUIResource(Color.black)
//			"TextArea.border", borderLowered
		};

		table.putDefaults( defaults );
	}

    /**
     * Turn the Vector of UI's into an array.
     */
    protected static ComponentUI[] uisToArray(Vector uis) {
        if (uis == null) {
            return new ComponentUI[0];
        } else {
            int count = uis.size();
            if (count > 0) {
                ComponentUI[] u = new ComponentUI[count];
                for (int i = 0; i < count; i++) {
                    u[i] = (ComponentUI)uis.elementAt(i);
                }
                return u;
            } else {
                return null;
            }
        }
    }


}

